Documentation
¶
Overview ¶
Copyright 2021 SANGFOR TECHNOLOGIES
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2021 SANGFOR TECHNOLOGIES ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2021 SANGFOR TECHNOLOGIES ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AgentHandler ¶
type AgentHandler interface {
RunTask(wp *dtstruct.WorkerPool, args *Args)
}
AgentHandler define method that agent adaptor need to implement
type Args ¶
type Args struct {
ServerAddr string // server will receive heartbeat request
AgtIp string // local ip will listen on
AgtPort int // local port
CheckInterval int // heartbeat interval
DisableHttp bool // disable http server or not
RefreshInterval int // refresh basic info interval
}
Args hold all args from cli when start
type HttpServer ¶
type HttpServer struct {
Server *http.Server
Limiter *rate.Limiter
Args *Args
Process func(*rate.Limiter, *Args, http.ResponseWriter)
}
HttpServer now is only to facilitate restful api test, check if agent and database is available
func (HttpServer) ServeHTTP ¶
func (hs HttpServer) ServeHTTP(writer http.ResponseWriter, request *http.Request)
ServeHTTP process http request